@@ -97,7 +97,7 @@ float gps_get_heading(appdata_t *appdata) {
   return retval;
 }
 
-float gps_get_epe(appdata_t *appdata) {
+float gps_get_eph(appdata_t *appdata) {
   float retval = NAN;
 
   g_mutex_lock(appdata->gps_state->mutex);
@@ -180,7 +180,6 @@ void gps_clear_fix(struct gps_fix_t *fixp) {
   fixp->altitude = NAN;
   fixp->ept = NAN;
   fixp->eph = NAN;
-  fixp->epv = NAN;
   fixp->epd = NAN;
   fixp->eps = NAN;
   fixp->epc = NAN;
@@ -211,15 +210,13 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	  /* C - cycle isn't supported by gpxview */
 	  /* D - utc time isn't supported by gpxview */
 	case 'E':
-	  gpsdata->epe = gpsdata->fix.eph = gpsdata->fix.epv = NAN;
+	  gpsdata->fix.eph = NAN;
 	  /* epe should always be present if eph or epv is */
 	  if (sp[2] != '?') {
 	    char epe[20], eph[20], epv[20];
 	    (void)sscanf(sp, "E=%s %s %s", epe, eph, epv);
 #define DEFAULT(val) (val[0] == '?') ? NAN : g_ascii_strtod(val, NULL)
-	    gpsdata->epe = DEFAULT(epe);
 	    gpsdata->fix.eph = DEFAULT(eph);
-	    gpsdata->fix.epv = DEFAULT(epv);
 #undef DEFAULT
 	  }
 	  break;
@@ -260,7 +257,6 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	      nf.ept = DEFAULT(ept);
 	      nf.altitude = DEFAULT(alt);
 	      nf.eph = DEFAULT(eph);
-	      nf.epv = DEFAULT(epv);
 	      nf.track = DEFAULT(track);
 	      nf.speed = DEFAULT(speed);
 	      nf.climb = DEFAULT(climb);
@@ -276,8 +272,6 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 		gpsdata->set |= ALTITUDE_SET | CLIMB_SET;
 	      if (isnan(nf.eph)==0)
 		gpsdata->set |= HERR_SET;
-	      if (isnan(nf.epv)==0)
-		gpsdata->set |= VERR_SET;
 	      if (isnan(nf.track)==0)
 		gpsdata->set |= TRACK_SET | SPEED_SET;
 	      if (isnan(nf.eps)==0)
@@ -507,7 +501,7 @@ location_changed(LocationGPSDevice *device, gps_state_t *gps_state) {
   if(gps_state->fields & LOCATION_GPS_DEVICE_LATLONG_SET) { 
     gps_state->latitude = device->fix->latitude;
     gps_state->longitude = device->fix->longitude;
-    gps_state->epe = device->fix->eph;
+    gps_state->eph = device->fix->eph/100.0;  // we want eph in meters
   }
 
   if(gps_state->fields & LOCATION_GPS_DEVICE_TRACK_SET)
@@ -618,13 +612,13 @@ float gps_get_heading(appdata_t *appdata) {
   return gps_state->heading; 
 }
 
-float gps_get_epe(appdata_t *appdata) { 
+float gps_get_eph(appdata_t *appdata) { 
   gps_state_t *gps_state = appdata->gps_state;
  
   if(!(gps_state->fields & LOCATION_GPS_DEVICE_LATLONG_SET))
     return NAN;
 
-  return gps_state->epe; 
+  return gps_state->eph; 
 }
 
 gps_sat_t *gps_get_sats(appdata_t *appdata) { 
