@@ -18,6 +18,7 @@
  */
 
 #include "gpxview.h"
+#include "converter.h"
 #include <math.h>    // for isnan
 
 #ifdef ENABLE_OSM_GPS_MAP
@@ -27,12 +28,6 @@
 #define MAP_SOURCE  OSM_GPS_MAP_SOURCE_OPENSTREETMAP
 #define GPS_DEFAULT_ZOOM 13
 
-/* equatorial radius in meters */
-#define EQ_RADIUS     (6378137.0)
-
-#define RAD2DEG(a)  (((a)*180.0)/M_PI)
-#define DEG2RAD(a)  (((a)*M_PI)/180.0)
-
 #define PROXY_KEY  "/system/http_proxy/"
 
 static const char *get_proxy_uri(appdata_t *appdata) {
@@ -71,39 +66,8 @@ static const char *get_proxy_uri(appdata_t *appdata) {
   return NULL;
 }
 
-static void map_zoom(map_context_t *context, int step) {
-  gint zoom;
-  OsmGpsMap *map = OSM_GPS_MAP(context->widget);
-  g_object_get(map, "zoom", &zoom, NULL);
-  zoom = osm_gps_map_set_zoom(map, zoom+step);
-
-  /* enable/disable zoom buttons as required */
-  gtk_widget_set_sensitive(context->zoomin, 
-	   zoom < osm_gps_map_source_get_max_zoom(MAP_SOURCE));
-  gtk_widget_set_sensitive(context->zoomout,
-	   zoom > osm_gps_map_source_get_min_zoom(MAP_SOURCE));
-
-  /* hmm ... this doesn't really work */
-  osm_gps_map_osd_speed(map, zoom);
-
-  /* save new zoom */
-  context->appdata->map.zoom = zoom;
-}
-
-static gboolean
-cb_map_zoomin(GtkButton *button, map_context_t *context) {
-  map_zoom(context, +1);
-  return FALSE;
-}
-
-static gboolean
-cb_map_zoomout(GtkButton *button, map_context_t *context) {
-  map_zoom(context, -1);
-  return FALSE;
-}
-
-static gboolean
-cb_map_gps(GtkButton *button, map_context_t *context) {
+static void
+cb_map_gps(map_context_t *context) {
   pos_t *refpos = get_pos(context->appdata);
   if(refpos && !isnan(refpos->lat) && !isnan(refpos->lon)) {
     osm_gps_map_set_mapcenter(OSM_GPS_MAP(context->widget),
@@ -113,20 +77,6 @@ cb_map_gps(GtkButton *button, map_context_t *context) {
     osm_gps_map_set_mapcenter(OSM_GPS_MAP(context->widget), 
 			      0.0, 0.0, 1);
   }
-
-  return FALSE;
-}
-
-static GtkWidget 
-*map_add_button(int icon, GCallback cb, gpointer data, 
-		char *tooltip) {
-  GtkWidget *button = gtk_button_new();
-  gtk_button_set_image(GTK_BUTTON(button), icon_get_widget(ICON_MISC, icon));
-  g_signal_connect(button, "clicked", cb, data);
-#ifndef USE_MAEMO
-  gtk_widget_set_tooltip_text(button, tooltip);
-#endif
-  return button;
 }
 
 static int dist2pixel(map_context_t *context, float km, float lat) {
@@ -141,7 +91,8 @@ static gboolean map_gps_update(gpointer data) {
   gboolean ok = (refpos!= NULL) && !isnan(refpos->lat) && !isnan(refpos->lon);
 
   /* ... and enable "goto" button if it's valid */
-  gtk_widget_set_sensitive(context->gps, ok);
+  osm_gps_map_osd_enable_gps (OSM_GPS_MAP(context->widget), 
+			      OSM_GPS_MAP_OSD_GPS_CALLBACK(ok?cb_map_gps:NULL), context);
 
   if(ok) {
     float heading = NAN;
@@ -251,8 +202,8 @@ static cache_t *map_closest(map_context_t *context, pos_t *pos) {
 /* translate between osm-gps-map positions and gpxview ones */
 pos_t coord2pos(coord_t coo) {
   pos_t pos;
-  pos.lat = RAD2DEG(coo.rlat);
-  pos.lon = RAD2DEG(coo.rlon);
+  pos.lat = rad2deg(coo.rlat);
+  pos.lon = rad2deg(coo.rlon);
   return pos;
 }
 
@@ -305,7 +256,11 @@ cairo_draw_pixbuf(cairo_t *cr, GdkPixbuf *buf, gint x, gint y) {
   cairo_paint(cr);
 }
 
+#ifndef BIG_BALLOONS
 #define LINE_SKIP  7
+#else
+#define LINE_SKIP  12
+#endif
 
 static void 
 balloon_draw_cb(cairo_t *cr, OsmGpsMapRect_t *rect, gpointer data) {
@@ -337,7 +292,12 @@ balloon_draw_cb(cairo_t *cr, OsmGpsMapRect_t *rect, gpointer data) {
 			    CAIRO_FONT_SLANT_NORMAL,
 			    CAIRO_FONT_WEIGHT_BOLD);
   
+#ifndef BIG_BALLOONS
     cairo_set_font_size (cr, 20.0);
+#else
+    cairo_set_font_size (cr, 36.0);
+#endif
+
     cairo_text_extents (cr, cache->id, &extents);
 
     /* display id right of icon vertically centered */
@@ -358,7 +318,11 @@ balloon_draw_cb(cairo_t *cr, OsmGpsMapRect_t *rect, gpointer data) {
   /* everything from here uses the same font */
   cairo_select_font_face (cr, "Sans", CAIRO_FONT_SLANT_NORMAL,
   			  CAIRO_FONT_WEIGHT_NORMAL);
+#ifndef BIG_BALLOONS
   cairo_set_font_size (cr, 14.0);
+#else
+  cairo_set_font_size (cr, 22.0);
+#endif
 
   if(cache->name) {
     /* draw cache name */
@@ -486,8 +450,6 @@ void map(appdata_t *appdata) {
   context = appdata->map.context = g_new0(map_context_t, 1);
   context->appdata = appdata;
 
-  GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
-
   char *path = g_strdup_printf("%s/map/", appdata->image_path);
   const char *proxy = get_proxy_uri(appdata);
 
@@ -550,30 +512,8 @@ void map(appdata_t *appdata) {
   g_signal_connect(G_OBJECT(context->widget), "button-release-event",
                    G_CALLBACK(on_map_button_release_event), context);
 
-  gtk_box_pack_start_defaults(GTK_BOX(hbox), context->widget);
-  /* zoom button box */
-  GtkWidget *vbox = gtk_vbox_new(FALSE,0);
-
-  context->zoomin = 
-    map_add_button(10, G_CALLBACK(cb_map_zoomin),
-                   context, _("Zoom in"));
-  gtk_box_pack_start(GTK_BOX(vbox), context->zoomin, FALSE, FALSE, 0);
-
-  context->zoomout = 
-    map_add_button(11, G_CALLBACK(cb_map_zoomout),
-                   context, _("Zoom out"));
-  gtk_box_pack_start(GTK_BOX(vbox), context->zoomout, FALSE, FALSE, 0);
-
-  context->gps = 
-    map_add_button(9, G_CALLBACK(cb_map_gps),
-		   context, _("Jump to GPS position"));
-  gtk_widget_set_sensitive(context->gps, FALSE);
-
   /* install handler for timed updates of the gps button */
   context->handler_id = gtk_timeout_add(1000, map_gps_update, context);
-  gtk_box_pack_start(GTK_BOX(vbox), context->gps, FALSE, FALSE, 0);
-
-  gtk_box_pack_start(GTK_BOX(hbox), vbox, FALSE, FALSE, 0);
 
 #if MAEMO_VERSION_MAJOR == 5
   /* prevent some of the main screen things */
@@ -584,6 +524,6 @@ void map(appdata_t *appdata) {
   g_signal_connect(G_OBJECT(context->window), "destroy", 
 		   G_CALLBACK(on_window_destroy), context);
 
-  gtk_container_add(GTK_CONTAINER(context->window), hbox); 
+  gtk_container_add(GTK_CONTAINER(context->window), context->widget); 
   gtk_widget_show_all(GTK_WIDGET(context->window));
 }
